@@ -15,6 +15,12 @@ from .projects import Projects
 from .departments import Departments
 from .charge_card_accounts import ChargeCardAccounts
 from .charge_card_transactions import ChargeCardTransactions
+from .customers import Customers
+from .items import Items
+from .ap_payments import APPayments
+from .reimbursements import Reimbursements
+from .checking_accounts import CheckingAccounts
+from .savings_accounts import SavingsAccounts
 
 __all_ = [
     'ApiBase',
@@ -30,5 +36,11 @@ __all_ = [
     'Projects',
     'Departments',
     'ChargeCardAccounts',
-    'ChargeCardTransactions'
+    'ChargeCardTransactions',
+    'Customers',
+    'Items',
+    'APPayments',
+    'Reimbursements',
+    'CheckingAccounts'
+    'SavingsAccounts'
 ]
